import {Component, ComponentInterface, Prop, h} from '@stencil/core';
import {CtaLinkVariants} from '../../utils/utils';

@Component({
  tag: 'hy-cta-link',
  styleUrl: 'cta-link.scss',
  shadow: true,
})
export class CtaLink implements ComponentInterface {
  @Prop() variant: CtaLinkVariants = CtaLinkVariants.default;
  @Prop() linkContent: string = '';
  @Prop() url?: string;
  @Prop() scLabel?: string;
  @Prop() isExternal: boolean = false;

  render() {
    const classAttributes = ['hy-cta-link', this.variant].join(' ');

    const containerClassAttributes = ['hy-cta-link-container'].join(' ');

    const textClassAttributes = ['text'].join(' ');
    const iconClassAttributes = ['link-icon', this.isExternal ? 'link-icon--external' : null].join(' ');
    const target = this.isExternal ? '_blank' : '_self';

    return (
      <span class={containerClassAttributes}>
        <a aria-label={this.scLabel} class={classAttributes} href={this.url} target={target}>
          {this.variant == CtaLinkVariants.linkList && (
            <span class={'hy-icon-wrapper'}>
              <div class={iconClassAttributes}>
                <hy-icon icon={'hy-icon-arrow-to-right'} size={40} />
              </div>
            </span>
          )}
          <span class={textClassAttributes}>{this.linkContent.length === 0 ? <slot /> : this.linkContent}</span>
          {this.variant == CtaLinkVariants.default && (
            <span class={iconClassAttributes}>
              <hy-icon icon={'hy-icon-arrow-right'} size={48} />
            </span>
          )}
        </a>
      </span>
    );
  }
}
