export interface FooterInfoLinks {
  label: string;
  url: string;
  isActive?: boolean;
  mainlink?: boolean;
  items: Array<FooterInfoLinks>;
}

import {Component, ComponentInterface, Element, Watch, Host, State, Prop, h} from '@stencil/core';
import ResizeObserver from 'resize-observer-polyfill';
import {HeadingVarians, FooterLinkItemColor, FooterLinkVariants} from '../../../utils/utils';

@Component({
  tag: 'hy-footer-info',
  styleUrl: 'hy-footer-info.scss',
  shadow: false,
})
export class HyFooterInfo implements ComponentInterface {
  @Element() el: HTMLElement;
  /**
   * Content area title.
   */
  @Prop() textTitle: string;
  /**
   * Content area text.
   */
  @Prop() textDescription: string;
  /**
   * Content area link button text.
   */
  @Prop() linkText: string;
  /**
   * Content area link button url.
   */
  @Prop() linkUrl: string;
  @State() isMobile: boolean;

  private ro: ResizeObserver;
  private _dataFooterInfoLinks: FooterInfoLinks[];
  /**
   * Data for links to be displayed.
   */
  @Prop() dataFooterInfoLinks: FooterInfoLinks[] | string;

  @Watch('dataFooterInfoLinks') dataFooterInfoLinksWatcher(data: FooterInfoLinks[] | string) {
    this._dataFooterInfoLinks = typeof data === 'string' ? JSON.parse(data) : data;
  }
  componentWillLoad() {
    this.dataFooterInfoLinksWatcher(this.dataFooterInfoLinks);
  }

  componentDidLoad() {
    this.ro = new ResizeObserver((entries) => {
      for (const entry of entries) {
        this.checkForMobile(entry.contentRect.width);
      }
    });
    this.ro.observe(document.body);
  }

  componentDidUnload() {
    this.ro.disconnect();
  }

  checkForMobile(size: number) {
    this.isMobile = size <= 479 ? true : false;
  }

  render() {
    const classAttributes = ['hy-footer-info'].join(' ');
    const links = this._dataFooterInfoLinks as Array<FooterInfoLinks>;
    const variant = FooterLinkVariants.campus;

    return (
      <Host class={classAttributes}>
        <div class="hy-footer-info__content">
          <hy-heading heading={HeadingVarians.h2}>{this.textTitle}</hy-heading>
          <div class="hy-footer-info__ingress">{this.textDescription}</div>
          {this.linkUrl && (
            <hy-button variant="secondary" icon-right="hy-icon-arrow-right" url={this.linkUrl} size={'large'}>
              {this.linkText}
            </hy-button>
          )}
        </div>
        {this.isMobile ? (
          <div class="hy-footer-info__links">
            <hy-accordion-container accordionid={'test'}>
              {links &&
                links.map((link) => {
                  return (
                    <hy-accordion-item accordiontitle={link.label}>
                      <hy-footer-link-item
                        class="campus"
                        variant={variant}
                        color={FooterLinkItemColor.black}
                        label={link.label}
                        url={link.url}
                        main-link={link.mainlink}
                        items={link.items}
                        isMobile={this.isMobile}
                      ></hy-footer-link-item>
                    </hy-accordion-item>
                  );
                })}
            </hy-accordion-container>
          </div>
        ) : (
          <div class="hy-footer-info__links">
            {links &&
              links.map((link) => {
                return (
                  <hy-footer-link-item
                    class="campus"
                    variant={variant}
                    color={FooterLinkItemColor.black}
                    label={link.label}
                    url={link.url}
                    main-link={link.mainlink}
                    items={link.items}
                    isMobile={this.isMobile}
                  ></hy-footer-link-item>
                );
              })}
          </div>
        )}
      </Host>
    );
  }
}
