import {Component, Prop, h, State, Element, Host} from '@stencil/core';
import {ColorVariant} from '../../utils/utils';

@Component({
  tag: 'hy-search-field',
  styleUrl: 'hy-search-field.scss',
  shadow: false,
})
export class HySearchField {
  @Element() el: HTMLElement;
  @Prop() label: string;
  @Prop() isLabelHidden?: boolean = false;
  @Prop() inputId: string;
  @State() isInputValueEmpty: boolean = true;

  componentDidLoad() {
    const searchInput = this.el.querySelector('.search-field__input');

    searchInput.addEventListener('keyup', (event) => {
      const {value} = event.target as HTMLInputElement;

      this.isInputValueEmpty = value.length > 0 ? false : true;
    });
  }

  handleInputReset() {
    this.isInputValueEmpty = true;
    const searchInput = this.el.querySelector('.search-field__input') as HTMLInputElement;
    searchInput.value = '';
    searchInput.focus();
  }

  render() {
    return (
      <Host class="search-field">
        <label htmlFor={this.inputId} class={`search-field__label ${this.isLabelHidden ? 'visually-hidden' : ''}`}>
          {this.label}
        </label>
        <div class="search-field__actions">
          <div class="search-field__wrapper">
            <input id={this.inputId} type="text" placeholder="Type here..." class="search-field__input" />
            {!this.isInputValueEmpty && (
              <button
                type="button"
                class="search-field__reset"
                aria-label="Reset"
                onClick={() => this.handleInputReset()}
              >
                <hy-icon icon={'hy-icon-remove'} size={14} aria-hidden="true" />
              </button>
            )}
          </div>
          <button type="submit" class="search-field__submit" aria-label="Search">
            <hy-icon icon={'hy-icon-search'} size={18} fill={ColorVariant.white} aria-hidden="true" />
          </button>
        </div>
      </Host>
    );
  }
}
